
Client-side state management
-------

**Description:**

An application can implement all kinds of logic rules through javascript and html. 
However, these are client-side constraints that a hacker can easily disable or modify.


**Solution:**

User restrictions should always be imposed by server side techniques instead 
of client side constraints.

	